Attribute VB_Name = "lib_trsrmt"
Option Explicit

' this enum represents the different TRsSIM remote commands that can be interpretted!
Enum trsrmt_cmd_e
    trs_cmd_NONE = -1   ' Not really a command - just means no command defined
    trs_cmd_DO = 0
    trs_cmd_EXIT = 1
    trs_cmd_FILE = 2
    trs_cmd_GET = 3
    trs_cmd_RESET = 4
    trs_cmd_SCRIPT = 5
    trs_cmd_DEV = 6
End Enum

' trsrmt error code definitions
Enum trsrmt_err_e
    terr_None = 0  '        /* No error */
    terr_Timeout = 1   '     /* Timeout Occured */
    terr_NoConnect = 2 '     /* Operation could not complete because TCP/IP connection is closed*/
    terr_SocketErr = 3 '     /* A socket error occured -- possibly due to the server closing the connection*/
    terr_BadParam = 4  '     /* A parameter is invalid*/
    
    ' parsing errors
    terr_BadResp = 5   '     /* response from the TRsSIM endpoint is in unknown format*/
    terr_BadOKLine = 6 '     /* something in the OK line of the response is bad!*/
    terr_NoCMDname = 7 '     /* could not recognize the Command name on the OK line of the response */
    terr_ERROR_Resp = 8 '     /* an ERROR message is contained in the TRsSIM response */
    terr_WARNING_Resp = 9 '        /* a WARNING message is contained in the TRsSIM response*/
    terr_WrongCMDResp = 10 '       /* detected response to incorrect command */
    terr_NoValidData = 11 '        /* the data required for the request isn't available -> wrong order of instructions*/
    terr_FieldNotFound = 12 '      /* the desired field couldn't be located*/
    terr_BadNumSamples = 13 '      /* The number of samples returned doesn't match the information in the header*/
    terr_BadSampleData = 14 '      /* format of the sample data returned in invalid*/
    terr_BadXSum = 15   '        /* checksum failure on the returned data*/
    terr_MemFail = 100   '       /* internal memory allocation failure (ie malloc() failed)*/
    terr_LogicBad = 101  '       /* unexpected logic error */
    terr_RespToBig = 102 '       /* response from server is too large! receive halted to prevent huge malloc statement!*/
End Enum

' This enum defines the possible return values for the script state
Enum trsrmt_scriptstate_e
    script_NOSTATUS = -1 '        /* not a real value -> just means parameter not initialized*/
    script_STOP = 0 '     /* no script program executing */
    script_RUN = 1 '     /* script is running */
    script_PAUSE = 2   '     /* script is paused */
    script_IDLE = 3 '     /* script is waiting for events */
    script_ERROR = 4   '     /* error detected in script program */
End Enum

' this defines the possible script control commands
Enum trsrmt_scriptcmd_e
    script_cmd_END = 0
    script_cmd_PAUSE = 1
    script_cmd_RESUME = 2
    script_cmd_RUN = 3
End Enum

' this represents the event selectors for DEV <identifier> GET EVENT <selector>
Enum trsrmt_eventsel_e
    eventsel_FIRST = 0
    eventsel_LAST = 1
    eventsel_NEXT = 2
    eventsel_PREV = 3
    eventsel_CURRENT = 4
End Enum

'***************************************************************************************************
'    Function Prototypes()
Public Declare Sub trsrmt_Get_Version Lib "trsrmt.dll" (ByRef Major As Long, ByRef Minor As Long)
Public Declare Function trsrmt_Connect Lib "trsrmt.dll" (ByVal ServerIP As String, ByVal Port As Long) As Long
Public Declare Sub trsrmt_Disconnect Lib "trsrmt.dll" ()
Public Declare Function trsrmt_Set_Timeout Lib "trsrmt.dll" (ByVal Timeout As Long) As Long
Public Declare Function trsrmt_SendCmd Lib "trsrmt.dll" (ByVal CmdData As String, ByVal CmdDataLen As Long) As Long
Public Declare Function trsrmt_WaitCmdResp Lib "trsrmt.dll" (ByRef ResponseLen As Long) As Long
Public Declare Function trsrmt_Get_RespLen Lib "trsrmt.dll" () As Long
Public Declare Function trsrmt_Get_Response Lib "trsrmt.dll" (ByVal Response As String, ByVal MaxLen As Long, ByRef CharsCopied As Long) As Long
Public Declare Function trsrmt_Get_ERROR_Msg Lib "trsrmt.dll" (ByVal ErrMsg As String, ByVal MaxLen As Long, ByRef CharsCopied As Long) As Long
Public Declare Function trsrmt_Get_WARNING_Msg Lib "trsrmt.dll" (ByVal WarnMsg As String, ByVal MaxLen As Long, ByRef CharsCopied As Long) As Long
Public Declare Function trsrmt_GET_DEVICES Lib "trsrmt.dll" (ByRef NumDevices As Long) As Long
Public Declare Function trsrmt_Get_DeviceInfo Lib "trsrmt.dll" (ByVal Index As Long, ByRef DeviceID As Long, ByVal Info As String, ByVal MaxLen As Long, ByRef CharsCopied As Long) As Long
Public Declare Function trsrmt_GET_LOG Lib "trsrmt.dll" (ByVal LogName As String, ByRef NumLogs As Long) As Long
Public Declare Function trsrmt_Get_LogInfo Lib "trsrmt.dll" (ByVal Index As Long, ByVal LogName As String, ByVal MaxLen As Long, ByRef LogSize As Long, ByRef CharsCopied As Long) As Long
Public Declare Function trsrmt_Get_LogContents Lib "trsrmt.dll" (ByVal Index As Long, ByVal LogContents As String, ByVal MaxLen As Long, ByRef CharsCopied As Long) As Long
Public Declare Function trsrmt_GET_STATUS Lib "trsrmt.dll" (ByRef ScriptStatus As Long, ByRef DoStatus As Long) As Long
Public Declare Function trsrmt_RESET Lib "trsrmt.dll" () As Long
Public Declare Function trsrmt_EXIT Lib "trsrmt.dll" () As Long
Public Declare Function trsrmt_DO Lib "trsrmt.dll" (ByVal script As String) As Long
Public Declare Function trsrmt_FILE_OPEN Lib "trsrmt.dll" (ByVal Filename As String) As Long
Public Declare Function trsrmt_SCRIPT_Ctrl Lib "trsrmt.dll" (ByVal Command As Long) As Long
Public Declare Function trsrmt_SCRIPT_SOURCE Lib "trsrmt.dll" (ByVal script As String) As Long
Public Declare Function trsrmt_DEV_GET_EVENT Lib "trsrmt.dll" (ByVal DeviceID As Long, ByVal EventSelector As Long, _
                ByRef EventIndex As Long, ByRef EventType As Long, ByVal EventName As String, ByVal MaxLen As Long, _
                ByRef CharsCopied As Long) As Long
Public Declare Function trsrmt_Get_EventTime Lib "trsrmt.dll" (ByRef Year As Long, ByRef Month As Long, _
                ByRef Day As Long, ByRef Hour As Long, ByRef Min As Long, ByRef Sec As Long, _
                ByRef TimeFromStart As Double) As Long
Public Declare Function trsrmt_Get_EventWaveInfo Lib "trsrmt.dll" (ByRef ACWaveRefNum As Long, ByRef DCWaveRefNum As Long) As Long
Public Declare Function trsrmt_Get_EventNumFields Lib "trsrmt.dll" (ByRef NumFields As Long) As Long
Public Declare Function trsrmt_Get_EventFieldName Lib "trsrmt.dll" (ByVal Index As Long, ByVal FieldName As String, ByVal MaxLen As Long, ByRef CharsCopied As Long) As Long
Public Declare Function trsrmt_Get_EventFieldValue Lib "trsrmt.dll" (ByVal FieldName As String, ByVal FieldValue As String, ByVal MaxLen As Long, ByRef CharsCopied As Long) As Long
Public Declare Function trsrmt_DEV_GET_WAVEINFO Lib "trsrmt.dll" (ByVal DeviceID As Long, ByVal RefNum As Long, _
                ByRef StartTime As Double, ByRef NumSamples As Long, ByRef SampleRate As Double, ByRef ScaleFact As Double, _
                ByRef MaxBlockSize As Long, ByRef BitsPerSample As Long, ByRef NumBlocks As Long) As Long
Public Declare Function trsrmt_DEV_GET_WAVEBLOCK Lib "trsrmt.dll" (ByVal DeviceID As Long, ByVal RefNum As Long, ByVal BlockNum As Long, _
                ByRef SampleData As Integer, ByVal MaxSamples As Long, ByRef SamplesCopied As Long) As Long
Public Declare Function trsrmt_Get_WaveformData Lib "trsrmt.dll" (ByVal DeviceID As Long, ByVal RefNum As Long, ByRef SampleData As Integer, ByVal MaxSamples As Long, ByRef SamplesCopied As Long) As Long
Public Declare Sub trsrmt_Get_FuncErrorMsg Lib "trsrmt.dll" (ByVal ECode As Long, ByVal Msg As String, ByVal MaxLen As Long, ByRef CharsCopied As Long)
