/* ***************************************************************
	TRsSIM remote control functions.
	see trsrmt.c for details
*/ 

#ifndef TRS_H_
#define	TRS_H_

// Unfortunately these are the re-definitions required for this code to compile in WINDOWS
#undef	FEXP
#ifdef WIN32
	#define	FEXP	WINAPI
	#define	__int16_t __int16
	#define	snprintf _snprintf
	#define strncasecmp	strnicmp
#else
	#define	FEXP
#endif

// this enum represents the different TRsSIM remote commands that can be interpretted!
#define	trsrmt_numcmds	7
typedef enum trsrmt_cmd_e{
	trs_cmd_NONE	=-1,	/* Not really a command - just means no command defined*/
	trs_cmd_DO	=0,
	trs_cmd_EXIT	=1,
	trs_cmd_FILE	=2,
	trs_cmd_GET	=3,
	trs_cmd_RESET	=4,
	trs_cmd_SCRIPT	=5,
	trs_cmd_DEV	=6,
}trsrmt_cmd_e;

// trsrmt error code definitions
enum trsrmt_err_e {
	terr_None	=0,		/* No error */
	terr_Timeout	=1,		/* Timeout Occured */
	terr_NoConnect	=2,		/* Operation could not complete because TCP/IP connection is closed*/
	terr_SocketErr	=3,		/* A socket error occured -- possibly due to the server closing the connection*/
	terr_BadParam	=4,		/* A parameter is invalid*/
	terr_BadResp	=5,		/* response from the TRsSIM endpoint is in unknown format*/
	terr_BadOKLine	=6,		/* something in the OK line of the response is bad!*/
	terr_NoCMDname	=7,		/* could not recognize the Command name on the OK line of the response */
	terr_ERROR_Resp	=8,		/* an ERROR message is contained in the TRsSIM response */
	terr_WARNING_Resp=9,		/* a WARNING message is contained in the TRsSIM response*/
	terr_WrongCMDResp=10,		/* detected response to incorrect command */	
	terr_NoValidData=11,		/* the data required for the request isn't available -> wrong order of instructions*/
	terr_FieldNotFound=12,		/* the desired field couldn't be located*/
	terr_BadNumSamples=13,		/* The number of samples returned doesn't match the information in the header*/
	terr_BadSampleData=14,		/* format of the sample data returned in invalid*/
	terr_BadXSum	=15,		/* checksum failure on the returned data*/
	terr_NoDelimAllowed=16,		/* as string argument accidentally contains an illegal character such as STX or ETX*/
	terr_MemFail	=100,		/* internal memory allocation failure (ie malloc() failed)*/
	terr_LogicBad	=101,		/* unexpected logic error */
	terr_RespToBig	=102,		/* response from server is too large! receive halted to prevent huge malloc statement!*/
};

// This enum defines the possible return values for the script state
#define	num_script_states	5
typedef enum trsrmt_scriptstate_e {
	script_NOSTATUS	=-1,		/* not a real value -> just means parameter not initialized*/
	script_STOP	=0,		/* no script program executing */
	script_RUN	=1,		/* script is running */
	script_PAUSE	=2,		/* script is paused */
	script_IDLE	=3,		/* script is waiting for events */
	script_ERROR	=4,		/* error detected in script program */
}trsrmt_scriptstate_e;

// this defines the possible script control commands
enum trsrmt_scriptcmd_e {
	script_cmd_END		=0,
	script_cmd_PAUSE	=1,
	script_cmd_RESUME	=2,
	script_cmd_RUN		=3,
};

// this represents the event selectors for DEV <identifier> GET EVENT <selector>
enum trsrmt_eventsel_e {
	eventsel_FIRST	=0,
	eventsel_LAST	=1,
	eventsel_NEXT	=2,
	eventsel_PREV	=3,
	eventsel_CURRENT=4,
};	

/* ***************************************************************************************************
	Function Prototypes
*/

// gets the version of this software
void FEXP trsrmt_Get_Version(long *Major, long *Minor);
// Returns an english error message related to a DLL error code
void FEXP trsrmt_Get_FuncErrorMsg(long ECode, char *ErrMsg, long MaxLen, long *CharsCopied);

// gets ERROR or WARNING messages from TRsSIM response (returns zero length string if condition not present)
long FEXP trsrmt_Get_ERROR_Msg(char *ErrMsg, long MaxLen, long *CharsCopied);
long FEXP trsrmt_Get_WARNING_Msg(char *WarnMsg, long MaxLen, long *CharsCopied);

// Connects and disconnects from TRsSIM server
long FEXP trsrmt_Connect(char *ServerIP, long Port);
void FEXP trsrmt_Disconnect();
long FEXP trsrmt_Set_Timeout(long Timeout);

// sends a text command surrounded by the STX,ETX characters
long FEXP trsrmt_SendCmd(char *CmdData, long CmdDataLen);
// waits for a response surrounded with STX,ETX and returns the length of the contents
long FEXP trsrmt_WaitCmdResp(long *ResponseLen);
// use the following functions to get the length and the contents of the unprocessed TRsSIM response
long FEXP trsrmt_Get_RespLen();
long FEXP trsrmt_Get_Response(char *Response, long MaxLen, long *CharsCopied);


// issues GET DEVICES and returns the number of devices detected in the response
long FEXP trsrmt_GET_DEVICES(long *NumDevices);
// returns the information on the nth device where n ranges from 1 to NumDevices
long FEXP trsrmt_Get_DeviceInfo(long Index,long *DeviceID, char *Info, long MaxLen, long *CharsCopied);

// functions for getting log names and contents
long FEXP trsrmt_GET_LOG(char *LogName, long *NumLogs);
long FEXP trsrmt_Get_LogInfo(long Index, char *LogName, long MaxLen, long *LogSize, long *CharsCopied);
long FEXP trsrmt_Get_LogContents(long Index, char *LogContents, long MaxLen, long *CharsCopied);

// issues GET STATUS and returns results
long FEXP trsrmt_GET_STATUS(long *ScriptStatus, long *DoStatus);

// resets TRsSIM
long FEXP trsrmt_RESET(void);
// shuts down TRsSIM
long FEXP trsrmt_EXIT(void);
// executes the script statements on TRsSIM
long FEXP trsrmt_DO(char *Script);
// opens a file in the TRsSIM software
long FEXP trsrmt_FILE_OPEN(char *Filename);
// control the execution of a script on TRsSIM
long FEXP trsrmt_SCRIPT_Ctrl(long Command);
// load script source into TRsSIM
long FEXP trsrmt_SCRIPT_SOURCE(char *Script);

// gets event information by issuing the DEV <ident> GET EVENT command
long FEXP trsrmt_DEV_GET_EVENT(long DeviceID, long EventSelector, 
				long *EventIndex, long *EventType, 
				char *EventName, long MaxLen, long *CharsCopied);
// this extracts the timing information from the GET EVENT response
long FEXP trsrmt_Get_EventTime(long *Year, long *Month, long *Day, long *Hour, long *Min, long *Sec, double *TimeFromStart);
// this extracts the waveform reference information from the GET EVENT response
long FEXP trsrmt_Get_EventWaveInfo(long *ACWaveRefNum, long *DCWaveRefNum);
// gets a field value from the event specific information
long FEXP trsrmt_Get_EventNumFields(long *NumFields);
long FEXP trsrmt_Get_EventFieldName(long Index, char *FieldName, long MaxLen, long *CharsCopied);				
long FEXP trsrmt_Get_EventFieldValue(char *FieldName, char *FieldValue, long MaxLen, long *CharsCopied);

// This returns information on a waveform based on a reference number
long FEXP trsrmt_DEV_GET_WAVEINFO(long DeviceID, long RefNum, double *StartTime, 
			long *NumSamples, double *SampleRate, 
			double *ScaleFact, long *MaxBlockSize, 
			long *BitsPerSample, long *NumBlocks);
// this returns a single block of waveform data
long FEXP trsrmt_DEV_GET_WAVEBLOCK(long DeviceID, long RefNum, long BlockNum, __int16_t *SampleData, long MaxSamples, long *SamplesCopied);
// this fucntion returns the entire data content of a waveform
long FEXP trsrmt_Get_WaveformData(long DeviceID, long RefNum, __int16_t *SampleData, long MaxSamples, long *SamplesCopied);



#endif /*TRS_H_*/


