﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;

namespace Advent.TrsRmt
{
    /// <summary>
    /// This class represents basic device information returned from the TRSSIM server
    /// </summary>
    public class DeviceInfo
    {
        public readonly char DeviceID = '?';
        /// <summary>
        /// This is the raw info string returned by the DLL
        /// </summary>
        public readonly String InfoString = "";
        /// <summary>
        /// This indicates the device status in TRSSIM.
        /// </summary>
        public readonly String Status = "";
        /// <summary>
        /// This is the device identifier associated with this device in TRSSIM.
        /// </summary>
        public readonly String Identifier = "";
        /// <summary>
        /// Serial number of this device in TRSSIM.
        /// </summary>
        public readonly String SerialNumber = "";
        /// <summary>
        /// Name of the device.
        /// </summary>
        public readonly String Name = "";
        /// <summary>
        /// Software version of this device.
        /// </summary>
        public readonly String SoftwareVersion = "";
        /// <summary>
        /// Hardware version of this device.
        /// </summary>
        public readonly String HardwareVersion = "";

        internal DeviceInfo(String Info)
        {
            this.InfoString = Info;
            ///* This info string is formatted as follows:
            // <status>:<identifier>:<serial number>:<name>:<soft vrs>:<hard vrs>
            //*/

            Info = Info.Substring(Info.IndexOf('='));       // we remove the '=' from the Dev=
            String[] p = Info.Split(':');
            int i = 0;
            for (i = 0; i < p.Length; i++)
            {
                switch (i)
                {
                    case 0:
                        this.Status = p[i];
                        break;
                    case 1:
                        this.Identifier = p[i];
                        this.DeviceID = p[i][0];
                        break;
                    case 2:
                        this.SerialNumber = p[i];
                        break;
                    case 3:
                        this.Name = p[i];
                        break;
                    case 4:
                        this.SoftwareVersion = p[i];
                        break;
                    case 5:
                        this.HardwareVersion = p[i];
                        break;
                }
            }
        }
    }
}
