﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;

namespace Advent.TrsRmt
{
    /// <summary>
    /// This class represents an event which can be read from the TRSSIM server
    /// </summary>
    public class Event
    {
        public readonly String Name = "";
        public readonly int EventType = 0;
        public readonly double Time = 0;
        public readonly DateTime PCTime = DateTime.MinValue;
        public readonly int ACWaveRefNum = 0;
        public readonly int DCWaveRefNum = 0;

        public readonly List<EventField> Fields;

        internal Event(String _Name, int _EventType, double _Time, DateTime _PCTime, int _ACWaveRefNum, int _DCWaveRefNUm, List<EventField> _EventFields)
        {
            this.Name = _Name;
            this.EventType = _EventType;
            this.Time = _Time;
            this.PCTime = _PCTime;
            this.ACWaveRefNum = _ACWaveRefNum;
            this.DCWaveRefNum = _DCWaveRefNUm;
            this.Fields = _EventFields;
        }
    }

    /// <summary>
    /// This represents a single measurement value for an event
    /// </summary>
    public class EventField
    {
        /// <summary>
        /// This returns the name of the event field.
        /// </summary>
        public readonly String Name = "";

        /// <summary>
        /// This returns the value of the event field. See TRSSIM documentation for the format of this string as it is dependent on the event type and field name.
        /// </summary>
        public readonly String Value = "";

        internal EventField(String _Name, String _Value)
        {
            this.Name = _Name;
            this.Value = _Value;
        }
    }

}
