﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;

namespace Advent.TrsRmt
{
    /// <summary>
    /// This represents information for a waveform which can be downloaded from TRSSIM
    /// </summary>
    public struct WaveformInfo
    {
        /// <summary>
        /// DeviceID of the device which was used to download this
        /// </summary>
        public int DeviceID;
        /// <summary>
        /// Waveform reference number of this waveform
        /// </summary>
        public int WaveformRefNum;

        /// <summary>
        /// Number of samples in the waveform
        /// </summary>
        public int NumSamples;
        /// <summary>
        /// Start time of this waveform in seconds.
        /// </summary>
        public double StartTime;
        /// <summary>
        /// Sample rate of this waveform in Hz
        /// </summary>
        public double SampleRate;
        /// <summary>
        /// Scale factor of this waveform to convert Integers to "Real" values
        /// </summary>
        public double ScaleFact;

        /// <summary>
        /// Maximum block size for this waveform
        /// </summary>
        public int MaxBlockSize;
        /// <summary>
        /// Resolution of each sample in bits.
        /// </summary>
        public int BitsPerSample;
        /// <summary>
        /// NUmber of blocks in the waveform
        /// </summary>
        public int NumBlocks;
    }

    /// <summary>
    /// This represents a waveform downloaded from TRSSIM
    /// </summary>
    public class Waveform
    {
        public double[] Samples = new double[0];
        public WaveformInfo Info = new WaveformInfo();
    }
}
